"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.metrics_pb2
import google.ads.google_ads.v4.proto.common.segments_pb2
import google.ads.google_ads.v4.proto.enums.summary_row_setting_pb2
import google.ads.google_ads.v4.proto.resources.account_budget_pb2
import google.ads.google_ads.v4.proto.resources.account_budget_proposal_pb2
import google.ads.google_ads.v4.proto.resources.account_link_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_ad_asset_view_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_ad_label_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_ad_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_audience_view_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_bid_modifier_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_criterion_label_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_criterion_simulation_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_extension_setting_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_feed_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_label_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_pb2
import google.ads.google_ads.v4.proto.resources.ad_group_simulation_pb2
import google.ads.google_ads.v4.proto.resources.ad_parameter_pb2
import google.ads.google_ads.v4.proto.resources.ad_schedule_view_pb2
import google.ads.google_ads.v4.proto.resources.age_range_view_pb2
import google.ads.google_ads.v4.proto.resources.asset_pb2
import google.ads.google_ads.v4.proto.resources.batch_job_pb2
import google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2
import google.ads.google_ads.v4.proto.resources.billing_setup_pb2
import google.ads.google_ads.v4.proto.resources.campaign_audience_view_pb2
import google.ads.google_ads.v4.proto.resources.campaign_bid_modifier_pb2
import google.ads.google_ads.v4.proto.resources.campaign_budget_pb2
import google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2
import google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2
import google.ads.google_ads.v4.proto.resources.campaign_draft_pb2
import google.ads.google_ads.v4.proto.resources.campaign_experiment_pb2
import google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2
import google.ads.google_ads.v4.proto.resources.campaign_feed_pb2
import google.ads.google_ads.v4.proto.resources.campaign_label_pb2
import google.ads.google_ads.v4.proto.resources.campaign_pb2
import google.ads.google_ads.v4.proto.resources.campaign_shared_set_pb2
import google.ads.google_ads.v4.proto.resources.carrier_constant_pb2
import google.ads.google_ads.v4.proto.resources.change_status_pb2
import google.ads.google_ads.v4.proto.resources.click_view_pb2
import google.ads.google_ads.v4.proto.resources.conversion_action_pb2
import google.ads.google_ads.v4.proto.resources.currency_constant_pb2
import google.ads.google_ads.v4.proto.resources.custom_interest_pb2
import google.ads.google_ads.v4.proto.resources.customer_client_link_pb2
import google.ads.google_ads.v4.proto.resources.customer_client_pb2
import google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2
import google.ads.google_ads.v4.proto.resources.customer_feed_pb2
import google.ads.google_ads.v4.proto.resources.customer_label_pb2
import google.ads.google_ads.v4.proto.resources.customer_manager_link_pb2
import google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2
import google.ads.google_ads.v4.proto.resources.customer_pb2
import google.ads.google_ads.v4.proto.resources.detail_placement_view_pb2
import google.ads.google_ads.v4.proto.resources.display_keyword_view_pb2
import google.ads.google_ads.v4.proto.resources.distance_view_pb2
import google.ads.google_ads.v4.proto.resources.domain_category_pb2
import google.ads.google_ads.v4.proto.resources.dynamic_search_ads_search_term_view_pb2
import google.ads.google_ads.v4.proto.resources.expanded_landing_page_view_pb2
import google.ads.google_ads.v4.proto.resources.extension_feed_item_pb2
import google.ads.google_ads.v4.proto.resources.feed_item_pb2
import google.ads.google_ads.v4.proto.resources.feed_item_target_pb2
import google.ads.google_ads.v4.proto.resources.feed_mapping_pb2
import google.ads.google_ads.v4.proto.resources.feed_pb2
import google.ads.google_ads.v4.proto.resources.feed_placeholder_view_pb2
import google.ads.google_ads.v4.proto.resources.gender_view_pb2
import google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2
import google.ads.google_ads.v4.proto.resources.geographic_view_pb2
import google.ads.google_ads.v4.proto.resources.group_placement_view_pb2
import google.ads.google_ads.v4.proto.resources.hotel_group_view_pb2
import google.ads.google_ads.v4.proto.resources.hotel_performance_view_pb2
import google.ads.google_ads.v4.proto.resources.income_range_view_pb2
import google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2
import google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_pb2
import google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_keyword_pb2
import google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_pb2
import google.ads.google_ads.v4.proto.resources.keyword_plan_pb2
import google.ads.google_ads.v4.proto.resources.keyword_view_pb2
import google.ads.google_ads.v4.proto.resources.label_pb2
import google.ads.google_ads.v4.proto.resources.landing_page_view_pb2
import google.ads.google_ads.v4.proto.resources.language_constant_pb2
import google.ads.google_ads.v4.proto.resources.location_view_pb2
import google.ads.google_ads.v4.proto.resources.managed_placement_view_pb2
import google.ads.google_ads.v4.proto.resources.media_file_pb2
import google.ads.google_ads.v4.proto.resources.mobile_app_category_constant_pb2
import google.ads.google_ads.v4.proto.resources.mobile_device_constant_pb2
import google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2
import google.ads.google_ads.v4.proto.resources.operating_system_version_constant_pb2
import google.ads.google_ads.v4.proto.resources.paid_organic_search_term_view_pb2
import google.ads.google_ads.v4.proto.resources.parental_status_view_pb2
import google.ads.google_ads.v4.proto.resources.product_bidding_category_constant_pb2
import google.ads.google_ads.v4.proto.resources.product_group_view_pb2
import google.ads.google_ads.v4.proto.resources.recommendation_pb2
import google.ads.google_ads.v4.proto.resources.remarketing_action_pb2
import google.ads.google_ads.v4.proto.resources.search_term_view_pb2
import google.ads.google_ads.v4.proto.resources.shared_criterion_pb2
import google.ads.google_ads.v4.proto.resources.shared_set_pb2
import google.ads.google_ads.v4.proto.resources.shopping_performance_view_pb2
import google.ads.google_ads.v4.proto.resources.third_party_app_analytics_link_pb2
import google.ads.google_ads.v4.proto.resources.topic_constant_pb2
import google.ads.google_ads.v4.proto.resources.topic_view_pb2
import google.ads.google_ads.v4.proto.resources.user_interest_pb2
import google.ads.google_ads.v4.proto.resources.user_list_pb2
import google.ads.google_ads.v4.proto.resources.user_location_view_pb2
import google.ads.google_ads.v4.proto.resources.video_pb2
import google.ads.google_ads.v4.proto.services.ad_group_ad_label_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_ad_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_bid_modifier_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_criterion_label_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_criterion_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_extension_setting_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_feed_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_label_service_pb2
import google.ads.google_ads.v4.proto.services.ad_group_service_pb2
import google.ads.google_ads.v4.proto.services.ad_parameter_service_pb2
import google.ads.google_ads.v4.proto.services.ad_service_pb2
import google.ads.google_ads.v4.proto.services.asset_service_pb2
import google.ads.google_ads.v4.proto.services.bidding_strategy_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_bid_modifier_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_budget_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_criterion_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_draft_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_experiment_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_extension_setting_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_feed_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_label_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_service_pb2
import google.ads.google_ads.v4.proto.services.campaign_shared_set_service_pb2
import google.ads.google_ads.v4.proto.services.conversion_action_service_pb2
import google.ads.google_ads.v4.proto.services.customer_extension_setting_service_pb2
import google.ads.google_ads.v4.proto.services.customer_feed_service_pb2
import google.ads.google_ads.v4.proto.services.customer_label_service_pb2
import google.ads.google_ads.v4.proto.services.customer_negative_criterion_service_pb2
import google.ads.google_ads.v4.proto.services.customer_service_pb2
import google.ads.google_ads.v4.proto.services.extension_feed_item_service_pb2
import google.ads.google_ads.v4.proto.services.feed_item_service_pb2
import google.ads.google_ads.v4.proto.services.feed_item_target_service_pb2
import google.ads.google_ads.v4.proto.services.feed_mapping_service_pb2
import google.ads.google_ads.v4.proto.services.feed_service_pb2
import google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_keyword_service_pb2
import google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_service_pb2
import google.ads.google_ads.v4.proto.services.keyword_plan_campaign_keyword_service_pb2
import google.ads.google_ads.v4.proto.services.keyword_plan_campaign_service_pb2
import google.ads.google_ads.v4.proto.services.keyword_plan_service_pb2
import google.ads.google_ads.v4.proto.services.label_service_pb2
import google.ads.google_ads.v4.proto.services.media_file_service_pb2
import google.ads.google_ads.v4.proto.services.remarketing_action_service_pb2
import google.ads.google_ads.v4.proto.services.shared_criterion_service_pb2
import google.ads.google_ads.v4.proto.services.shared_set_service_pb2
import google.ads.google_ads.v4.proto.services.user_list_service_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SearchGoogleAdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    RETURN_TOTAL_RESULTS_COUNT_FIELD_NUMBER: builtins.int
    SUMMARY_ROW_SETTING_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    query: typing.Text = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    validate_only: builtins.bool = ...
    return_total_results_count: builtins.bool = ...
    summary_row_setting: google.ads.google_ads.v4.proto.enums.summary_row_setting_pb2.SummaryRowSettingEnum.SummaryRowSetting.V = (
        ...
    )
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        query: typing.Text = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
        validate_only: builtins.bool = ...,
        return_total_results_count: builtins.bool = ...,
        summary_row_setting: google.ads.google_ads.v4.proto.enums.summary_row_setting_pb2.SummaryRowSettingEnum.SummaryRowSetting.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "query",
            b"query",
            "return_total_results_count",
            b"return_total_results_count",
            "summary_row_setting",
            b"summary_row_setting",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___SearchGoogleAdsRequest = SearchGoogleAdsRequest

class SearchGoogleAdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_RESULTS_COUNT_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    SUMMARY_ROW_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    total_results_count: builtins.int = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GoogleAdsRow
    ]: ...
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def summary_row(self) -> global___GoogleAdsRow: ...
    def __init__(
        self,
        *,
        results: typing.Optional[typing.Iterable[global___GoogleAdsRow]] = ...,
        next_page_token: typing.Text = ...,
        total_results_count: builtins.int = ...,
        field_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        summary_row: typing.Optional[global___GoogleAdsRow] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "field_mask", b"field_mask", "summary_row", b"summary_row"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "field_mask",
            b"field_mask",
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "summary_row",
            b"summary_row",
            "total_results_count",
            b"total_results_count",
        ],
    ) -> None: ...

global___SearchGoogleAdsResponse = SearchGoogleAdsResponse

class SearchGoogleAdsStreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    SUMMARY_ROW_SETTING_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    query: typing.Text = ...
    summary_row_setting: google.ads.google_ads.v4.proto.enums.summary_row_setting_pb2.SummaryRowSettingEnum.SummaryRowSetting.V = (
        ...
    )
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        query: typing.Text = ...,
        summary_row_setting: google.ads.google_ads.v4.proto.enums.summary_row_setting_pb2.SummaryRowSettingEnum.SummaryRowSetting.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "query",
            b"query",
            "summary_row_setting",
            b"summary_row_setting",
        ],
    ) -> None: ...

global___SearchGoogleAdsStreamRequest = SearchGoogleAdsStreamRequest

class SearchGoogleAdsStreamResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    FIELD_MASK_FIELD_NUMBER: builtins.int
    SUMMARY_ROW_FIELD_NUMBER: builtins.int
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___GoogleAdsRow
    ]: ...
    @property
    def field_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def summary_row(self) -> global___GoogleAdsRow: ...
    def __init__(
        self,
        *,
        results: typing.Optional[typing.Iterable[global___GoogleAdsRow]] = ...,
        field_mask: typing.Optional[google.protobuf.field_mask_pb2.FieldMask] = ...,
        summary_row: typing.Optional[global___GoogleAdsRow] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "field_mask", b"field_mask", "summary_row", b"summary_row"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "field_mask",
            b"field_mask",
            "results",
            b"results",
            "summary_row",
            b"summary_row",
        ],
    ) -> None: ...

global___SearchGoogleAdsStreamResponse = SearchGoogleAdsStreamResponse

class GoogleAdsRow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACCOUNT_BUDGET_FIELD_NUMBER: builtins.int
    ACCOUNT_BUDGET_PROPOSAL_FIELD_NUMBER: builtins.int
    ACCOUNT_LINK_FIELD_NUMBER: builtins.int
    AD_GROUP_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_ASSET_VIEW_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_LABEL_FIELD_NUMBER: builtins.int
    AD_GROUP_AUDIENCE_VIEW_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_LABEL_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_SIMULATION_FIELD_NUMBER: builtins.int
    AD_GROUP_EXTENSION_SETTING_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_FIELD_NUMBER: builtins.int
    AD_GROUP_LABEL_FIELD_NUMBER: builtins.int
    AD_GROUP_SIMULATION_FIELD_NUMBER: builtins.int
    AD_PARAMETER_FIELD_NUMBER: builtins.int
    AGE_RANGE_VIEW_FIELD_NUMBER: builtins.int
    AD_SCHEDULE_VIEW_FIELD_NUMBER: builtins.int
    DOMAIN_CATEGORY_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    BATCH_JOB_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_FIELD_NUMBER: builtins.int
    BILLING_SETUP_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_FIELD_NUMBER: builtins.int
    CAMPAIGN_FIELD_NUMBER: builtins.int
    CAMPAIGN_AUDIENCE_VIEW_FIELD_NUMBER: builtins.int
    CAMPAIGN_BID_MODIFIER_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_SIMULATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXPERIMENT_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXTENSION_SETTING_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_FIELD_NUMBER: builtins.int
    CAMPAIGN_LABEL_FIELD_NUMBER: builtins.int
    CAMPAIGN_SHARED_SET_FIELD_NUMBER: builtins.int
    CARRIER_CONSTANT_FIELD_NUMBER: builtins.int
    CHANGE_STATUS_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    CLICK_VIEW_FIELD_NUMBER: builtins.int
    CURRENCY_CONSTANT_FIELD_NUMBER: builtins.int
    CUSTOM_INTEREST_FIELD_NUMBER: builtins.int
    CUSTOMER_FIELD_NUMBER: builtins.int
    CUSTOMER_MANAGER_LINK_FIELD_NUMBER: builtins.int
    CUSTOMER_CLIENT_LINK_FIELD_NUMBER: builtins.int
    CUSTOMER_CLIENT_FIELD_NUMBER: builtins.int
    CUSTOMER_EXTENSION_SETTING_FIELD_NUMBER: builtins.int
    CUSTOMER_FEED_FIELD_NUMBER: builtins.int
    CUSTOMER_LABEL_FIELD_NUMBER: builtins.int
    CUSTOMER_NEGATIVE_CRITERION_FIELD_NUMBER: builtins.int
    DETAIL_PLACEMENT_VIEW_FIELD_NUMBER: builtins.int
    DISPLAY_KEYWORD_VIEW_FIELD_NUMBER: builtins.int
    DISTANCE_VIEW_FIELD_NUMBER: builtins.int
    DYNAMIC_SEARCH_ADS_SEARCH_TERM_VIEW_FIELD_NUMBER: builtins.int
    EXPANDED_LANDING_PAGE_VIEW_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEM_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_FIELD_NUMBER: builtins.int
    FEED_MAPPING_FIELD_NUMBER: builtins.int
    FEED_PLACEHOLDER_VIEW_FIELD_NUMBER: builtins.int
    GENDER_VIEW_FIELD_NUMBER: builtins.int
    GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    GEOGRAPHIC_VIEW_FIELD_NUMBER: builtins.int
    GROUP_PLACEMENT_VIEW_FIELD_NUMBER: builtins.int
    HOTEL_GROUP_VIEW_FIELD_NUMBER: builtins.int
    HOTEL_PERFORMANCE_VIEW_FIELD_NUMBER: builtins.int
    INCOME_RANGE_VIEW_FIELD_NUMBER: builtins.int
    KEYWORD_VIEW_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_KEYWORD_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_KEYWORD_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    LANDING_PAGE_VIEW_FIELD_NUMBER: builtins.int
    LANGUAGE_CONSTANT_FIELD_NUMBER: builtins.int
    LOCATION_VIEW_FIELD_NUMBER: builtins.int
    MANAGED_PLACEMENT_VIEW_FIELD_NUMBER: builtins.int
    MEDIA_FILE_FIELD_NUMBER: builtins.int
    MOBILE_APP_CATEGORY_CONSTANT_FIELD_NUMBER: builtins.int
    MOBILE_DEVICE_CONSTANT_FIELD_NUMBER: builtins.int
    OFFLINE_USER_DATA_JOB_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_VERSION_CONSTANT_FIELD_NUMBER: builtins.int
    PAID_ORGANIC_SEARCH_TERM_VIEW_FIELD_NUMBER: builtins.int
    PARENTAL_STATUS_VIEW_FIELD_NUMBER: builtins.int
    PRODUCT_BIDDING_CATEGORY_CONSTANT_FIELD_NUMBER: builtins.int
    PRODUCT_GROUP_VIEW_FIELD_NUMBER: builtins.int
    RECOMMENDATION_FIELD_NUMBER: builtins.int
    SEARCH_TERM_VIEW_FIELD_NUMBER: builtins.int
    SHARED_CRITERION_FIELD_NUMBER: builtins.int
    SHARED_SET_FIELD_NUMBER: builtins.int
    SHOPPING_PERFORMANCE_VIEW_FIELD_NUMBER: builtins.int
    THIRD_PARTY_APP_ANALYTICS_LINK_FIELD_NUMBER: builtins.int
    TOPIC_VIEW_FIELD_NUMBER: builtins.int
    USER_INTEREST_FIELD_NUMBER: builtins.int
    USER_LIST_FIELD_NUMBER: builtins.int
    USER_LOCATION_VIEW_FIELD_NUMBER: builtins.int
    REMARKETING_ACTION_FIELD_NUMBER: builtins.int
    TOPIC_CONSTANT_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    @property
    def account_budget(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.account_budget_pb2.AccountBudget: ...
    @property
    def account_budget_proposal(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal: ...
    @property
    def account_link(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.account_link_pb2.AccountLink: ...
    @property
    def ad_group(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_pb2.AdGroup: ...
    @property
    def ad_group_ad(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_ad_pb2.AdGroupAd: ...
    @property
    def ad_group_ad_asset_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView: ...
    @property
    def ad_group_ad_label(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_ad_label_pb2.AdGroupAdLabel: ...
    @property
    def ad_group_audience_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_audience_view_pb2.AdGroupAudienceView: ...
    @property
    def ad_group_bid_modifier(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier: ...
    @property
    def ad_group_criterion(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2.AdGroupCriterion: ...
    @property
    def ad_group_criterion_label(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_criterion_label_pb2.AdGroupCriterionLabel: ...
    @property
    def ad_group_criterion_simulation(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_criterion_simulation_pb2.AdGroupCriterionSimulation: ...
    @property
    def ad_group_extension_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting: ...
    @property
    def ad_group_feed(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_feed_pb2.AdGroupFeed: ...
    @property
    def ad_group_label(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_label_pb2.AdGroupLabel: ...
    @property
    def ad_group_simulation(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_group_simulation_pb2.AdGroupSimulation: ...
    @property
    def ad_parameter(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_parameter_pb2.AdParameter: ...
    @property
    def age_range_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.age_range_view_pb2.AgeRangeView: ...
    @property
    def ad_schedule_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.ad_schedule_view_pb2.AdScheduleView: ...
    @property
    def domain_category(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory: ...
    @property
    def asset(self) -> google.ads.google_ads.v4.proto.resources.asset_pb2.Asset: ...
    @property
    def batch_job(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.batch_job_pb2.BatchJob: ...
    @property
    def bidding_strategy(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy: ...
    @property
    def billing_setup(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.billing_setup_pb2.BillingSetup: ...
    @property
    def campaign_budget(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_budget_pb2.CampaignBudget: ...
    @property
    def campaign(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_pb2.Campaign: ...
    @property
    def campaign_audience_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_audience_view_pb2.CampaignAudienceView: ...
    @property
    def campaign_bid_modifier(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier: ...
    @property
    def campaign_criterion(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion: ...
    @property
    def campaign_criterion_simulation(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2.CampaignCriterionSimulation: ...
    @property
    def campaign_draft(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_draft_pb2.CampaignDraft: ...
    @property
    def campaign_experiment(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_experiment_pb2.CampaignExperiment: ...
    @property
    def campaign_extension_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2.CampaignExtensionSetting: ...
    @property
    def campaign_feed(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_feed_pb2.CampaignFeed: ...
    @property
    def campaign_label(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_label_pb2.CampaignLabel: ...
    @property
    def campaign_shared_set(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_shared_set_pb2.CampaignSharedSet: ...
    @property
    def carrier_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.carrier_constant_pb2.CarrierConstant: ...
    @property
    def change_status(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.change_status_pb2.ChangeStatus: ...
    @property
    def conversion_action(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.conversion_action_pb2.ConversionAction: ...
    @property
    def click_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.click_view_pb2.ClickView: ...
    @property
    def currency_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.currency_constant_pb2.CurrencyConstant: ...
    @property
    def custom_interest(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest: ...
    @property
    def customer(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_pb2.Customer: ...
    @property
    def customer_manager_link(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_manager_link_pb2.CustomerManagerLink: ...
    @property
    def customer_client_link(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_client_link_pb2.CustomerClientLink: ...
    @property
    def customer_client(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_client_pb2.CustomerClient: ...
    @property
    def customer_extension_setting(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting: ...
    @property
    def customer_feed(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed: ...
    @property
    def customer_label(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel: ...
    @property
    def customer_negative_criterion(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2.CustomerNegativeCriterion: ...
    @property
    def detail_placement_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.detail_placement_view_pb2.DetailPlacementView: ...
    @property
    def display_keyword_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.display_keyword_view_pb2.DisplayKeywordView: ...
    @property
    def distance_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView: ...
    @property
    def dynamic_search_ads_search_term_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.dynamic_search_ads_search_term_view_pb2.DynamicSearchAdsSearchTermView: ...
    @property
    def expanded_landing_page_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.expanded_landing_page_view_pb2.ExpandedLandingPageView: ...
    @property
    def extension_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.extension_feed_item_pb2.ExtensionFeedItem: ...
    @property
    def feed(self) -> google.ads.google_ads.v4.proto.resources.feed_pb2.Feed: ...
    @property
    def feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_pb2.FeedItem: ...
    @property
    def feed_item_target(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget: ...
    @property
    def feed_mapping(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping: ...
    @property
    def feed_placeholder_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.feed_placeholder_view_pb2.FeedPlaceholderView: ...
    @property
    def gender_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.gender_view_pb2.GenderView: ...
    @property
    def geo_target_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant: ...
    @property
    def geographic_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView: ...
    @property
    def group_placement_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.group_placement_view_pb2.GroupPlacementView: ...
    @property
    def hotel_group_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.hotel_group_view_pb2.HotelGroupView: ...
    @property
    def hotel_performance_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.hotel_performance_view_pb2.HotelPerformanceView: ...
    @property
    def income_range_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.income_range_view_pb2.IncomeRangeView: ...
    @property
    def keyword_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_view_pb2.KeywordView: ...
    @property
    def keyword_plan(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_pb2.KeywordPlan: ...
    @property
    def keyword_plan_campaign(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_pb2.KeywordPlanCampaign: ...
    @property
    def keyword_plan_campaign_keyword(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword: ...
    @property
    def keyword_plan_ad_group(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup: ...
    @property
    def keyword_plan_ad_group_keyword(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword: ...
    @property
    def label(self) -> google.ads.google_ads.v4.proto.resources.label_pb2.Label: ...
    @property
    def landing_page_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.landing_page_view_pb2.LandingPageView: ...
    @property
    def language_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.language_constant_pb2.LanguageConstant: ...
    @property
    def location_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.location_view_pb2.LocationView: ...
    @property
    def managed_placement_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.managed_placement_view_pb2.ManagedPlacementView: ...
    @property
    def media_file(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile: ...
    @property
    def mobile_app_category_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.mobile_app_category_constant_pb2.MobileAppCategoryConstant: ...
    @property
    def mobile_device_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.mobile_device_constant_pb2.MobileDeviceConstant: ...
    @property
    def offline_user_data_job(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob: ...
    @property
    def operating_system_version_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.operating_system_version_constant_pb2.OperatingSystemVersionConstant: ...
    @property
    def paid_organic_search_term_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.paid_organic_search_term_view_pb2.PaidOrganicSearchTermView: ...
    @property
    def parental_status_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.parental_status_view_pb2.ParentalStatusView: ...
    @property
    def product_bidding_category_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.product_bidding_category_constant_pb2.ProductBiddingCategoryConstant: ...
    @property
    def product_group_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.product_group_view_pb2.ProductGroupView: ...
    @property
    def recommendation(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.recommendation_pb2.Recommendation: ...
    @property
    def search_term_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.search_term_view_pb2.SearchTermView: ...
    @property
    def shared_criterion(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.shared_criterion_pb2.SharedCriterion: ...
    @property
    def shared_set(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.shared_set_pb2.SharedSet: ...
    @property
    def shopping_performance_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView: ...
    @property
    def third_party_app_analytics_link(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.third_party_app_analytics_link_pb2.ThirdPartyAppAnalyticsLink: ...
    @property
    def topic_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.topic_view_pb2.TopicView: ...
    @property
    def user_interest(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.user_interest_pb2.UserInterest: ...
    @property
    def user_list(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.user_list_pb2.UserList: ...
    @property
    def user_location_view(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.user_location_view_pb2.UserLocationView: ...
    @property
    def remarketing_action(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.remarketing_action_pb2.RemarketingAction: ...
    @property
    def topic_constant(
        self,
    ) -> google.ads.google_ads.v4.proto.resources.topic_constant_pb2.TopicConstant: ...
    @property
    def video(self) -> google.ads.google_ads.v4.proto.resources.video_pb2.Video: ...
    @property
    def metrics(self) -> google.ads.google_ads.v4.proto.common.metrics_pb2.Metrics: ...
    @property
    def segments(
        self,
    ) -> google.ads.google_ads.v4.proto.common.segments_pb2.Segments: ...
    def __init__(
        self,
        *,
        account_budget: typing.Optional[
            google.ads.google_ads.v4.proto.resources.account_budget_pb2.AccountBudget
        ] = ...,
        account_budget_proposal: typing.Optional[
            google.ads.google_ads.v4.proto.resources.account_budget_proposal_pb2.AccountBudgetProposal
        ] = ...,
        account_link: typing.Optional[
            google.ads.google_ads.v4.proto.resources.account_link_pb2.AccountLink
        ] = ...,
        ad_group: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_pb2.AdGroup
        ] = ...,
        ad_group_ad: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_ad_pb2.AdGroupAd
        ] = ...,
        ad_group_ad_asset_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_ad_asset_view_pb2.AdGroupAdAssetView
        ] = ...,
        ad_group_ad_label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_ad_label_pb2.AdGroupAdLabel
        ] = ...,
        ad_group_audience_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_audience_view_pb2.AdGroupAudienceView
        ] = ...,
        ad_group_bid_modifier: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_bid_modifier_pb2.AdGroupBidModifier
        ] = ...,
        ad_group_criterion: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_criterion_pb2.AdGroupCriterion
        ] = ...,
        ad_group_criterion_label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_criterion_label_pb2.AdGroupCriterionLabel
        ] = ...,
        ad_group_criterion_simulation: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_criterion_simulation_pb2.AdGroupCriterionSimulation
        ] = ...,
        ad_group_extension_setting: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_extension_setting_pb2.AdGroupExtensionSetting
        ] = ...,
        ad_group_feed: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_feed_pb2.AdGroupFeed
        ] = ...,
        ad_group_label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_label_pb2.AdGroupLabel
        ] = ...,
        ad_group_simulation: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_group_simulation_pb2.AdGroupSimulation
        ] = ...,
        ad_parameter: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_parameter_pb2.AdParameter
        ] = ...,
        age_range_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.age_range_view_pb2.AgeRangeView
        ] = ...,
        ad_schedule_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.ad_schedule_view_pb2.AdScheduleView
        ] = ...,
        domain_category: typing.Optional[
            google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory
        ] = ...,
        asset: typing.Optional[
            google.ads.google_ads.v4.proto.resources.asset_pb2.Asset
        ] = ...,
        batch_job: typing.Optional[
            google.ads.google_ads.v4.proto.resources.batch_job_pb2.BatchJob
        ] = ...,
        bidding_strategy: typing.Optional[
            google.ads.google_ads.v4.proto.resources.bidding_strategy_pb2.BiddingStrategy
        ] = ...,
        billing_setup: typing.Optional[
            google.ads.google_ads.v4.proto.resources.billing_setup_pb2.BillingSetup
        ] = ...,
        campaign_budget: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_budget_pb2.CampaignBudget
        ] = ...,
        campaign: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_pb2.Campaign
        ] = ...,
        campaign_audience_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_audience_view_pb2.CampaignAudienceView
        ] = ...,
        campaign_bid_modifier: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_bid_modifier_pb2.CampaignBidModifier
        ] = ...,
        campaign_criterion: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_criterion_pb2.CampaignCriterion
        ] = ...,
        campaign_criterion_simulation: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2.CampaignCriterionSimulation
        ] = ...,
        campaign_draft: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_draft_pb2.CampaignDraft
        ] = ...,
        campaign_experiment: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_experiment_pb2.CampaignExperiment
        ] = ...,
        campaign_extension_setting: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2.CampaignExtensionSetting
        ] = ...,
        campaign_feed: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_feed_pb2.CampaignFeed
        ] = ...,
        campaign_label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_label_pb2.CampaignLabel
        ] = ...,
        campaign_shared_set: typing.Optional[
            google.ads.google_ads.v4.proto.resources.campaign_shared_set_pb2.CampaignSharedSet
        ] = ...,
        carrier_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.carrier_constant_pb2.CarrierConstant
        ] = ...,
        change_status: typing.Optional[
            google.ads.google_ads.v4.proto.resources.change_status_pb2.ChangeStatus
        ] = ...,
        conversion_action: typing.Optional[
            google.ads.google_ads.v4.proto.resources.conversion_action_pb2.ConversionAction
        ] = ...,
        click_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.click_view_pb2.ClickView
        ] = ...,
        currency_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.currency_constant_pb2.CurrencyConstant
        ] = ...,
        custom_interest: typing.Optional[
            google.ads.google_ads.v4.proto.resources.custom_interest_pb2.CustomInterest
        ] = ...,
        customer: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_pb2.Customer
        ] = ...,
        customer_manager_link: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_manager_link_pb2.CustomerManagerLink
        ] = ...,
        customer_client_link: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_client_link_pb2.CustomerClientLink
        ] = ...,
        customer_client: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_client_pb2.CustomerClient
        ] = ...,
        customer_extension_setting: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_extension_setting_pb2.CustomerExtensionSetting
        ] = ...,
        customer_feed: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_feed_pb2.CustomerFeed
        ] = ...,
        customer_label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_label_pb2.CustomerLabel
        ] = ...,
        customer_negative_criterion: typing.Optional[
            google.ads.google_ads.v4.proto.resources.customer_negative_criterion_pb2.CustomerNegativeCriterion
        ] = ...,
        detail_placement_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.detail_placement_view_pb2.DetailPlacementView
        ] = ...,
        display_keyword_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.display_keyword_view_pb2.DisplayKeywordView
        ] = ...,
        distance_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.distance_view_pb2.DistanceView
        ] = ...,
        dynamic_search_ads_search_term_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.dynamic_search_ads_search_term_view_pb2.DynamicSearchAdsSearchTermView
        ] = ...,
        expanded_landing_page_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.expanded_landing_page_view_pb2.ExpandedLandingPageView
        ] = ...,
        extension_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.resources.extension_feed_item_pb2.ExtensionFeedItem
        ] = ...,
        feed: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_pb2.Feed
        ] = ...,
        feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_item_pb2.FeedItem
        ] = ...,
        feed_item_target: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_item_target_pb2.FeedItemTarget
        ] = ...,
        feed_mapping: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_mapping_pb2.FeedMapping
        ] = ...,
        feed_placeholder_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.feed_placeholder_view_pb2.FeedPlaceholderView
        ] = ...,
        gender_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.gender_view_pb2.GenderView
        ] = ...,
        geo_target_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.geo_target_constant_pb2.GeoTargetConstant
        ] = ...,
        geographic_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.geographic_view_pb2.GeographicView
        ] = ...,
        group_placement_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.group_placement_view_pb2.GroupPlacementView
        ] = ...,
        hotel_group_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.hotel_group_view_pb2.HotelGroupView
        ] = ...,
        hotel_performance_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.hotel_performance_view_pb2.HotelPerformanceView
        ] = ...,
        income_range_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.income_range_view_pb2.IncomeRangeView
        ] = ...,
        keyword_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_view_pb2.KeywordView
        ] = ...,
        keyword_plan: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_plan_pb2.KeywordPlan
        ] = ...,
        keyword_plan_campaign: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_pb2.KeywordPlanCampaign
        ] = ...,
        keyword_plan_campaign_keyword: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_plan_campaign_keyword_pb2.KeywordPlanCampaignKeyword
        ] = ...,
        keyword_plan_ad_group: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_pb2.KeywordPlanAdGroup
        ] = ...,
        keyword_plan_ad_group_keyword: typing.Optional[
            google.ads.google_ads.v4.proto.resources.keyword_plan_ad_group_keyword_pb2.KeywordPlanAdGroupKeyword
        ] = ...,
        label: typing.Optional[
            google.ads.google_ads.v4.proto.resources.label_pb2.Label
        ] = ...,
        landing_page_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.landing_page_view_pb2.LandingPageView
        ] = ...,
        language_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.language_constant_pb2.LanguageConstant
        ] = ...,
        location_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.location_view_pb2.LocationView
        ] = ...,
        managed_placement_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.managed_placement_view_pb2.ManagedPlacementView
        ] = ...,
        media_file: typing.Optional[
            google.ads.google_ads.v4.proto.resources.media_file_pb2.MediaFile
        ] = ...,
        mobile_app_category_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.mobile_app_category_constant_pb2.MobileAppCategoryConstant
        ] = ...,
        mobile_device_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.mobile_device_constant_pb2.MobileDeviceConstant
        ] = ...,
        offline_user_data_job: typing.Optional[
            google.ads.google_ads.v4.proto.resources.offline_user_data_job_pb2.OfflineUserDataJob
        ] = ...,
        operating_system_version_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.operating_system_version_constant_pb2.OperatingSystemVersionConstant
        ] = ...,
        paid_organic_search_term_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.paid_organic_search_term_view_pb2.PaidOrganicSearchTermView
        ] = ...,
        parental_status_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.parental_status_view_pb2.ParentalStatusView
        ] = ...,
        product_bidding_category_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.product_bidding_category_constant_pb2.ProductBiddingCategoryConstant
        ] = ...,
        product_group_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.product_group_view_pb2.ProductGroupView
        ] = ...,
        recommendation: typing.Optional[
            google.ads.google_ads.v4.proto.resources.recommendation_pb2.Recommendation
        ] = ...,
        search_term_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.search_term_view_pb2.SearchTermView
        ] = ...,
        shared_criterion: typing.Optional[
            google.ads.google_ads.v4.proto.resources.shared_criterion_pb2.SharedCriterion
        ] = ...,
        shared_set: typing.Optional[
            google.ads.google_ads.v4.proto.resources.shared_set_pb2.SharedSet
        ] = ...,
        shopping_performance_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.shopping_performance_view_pb2.ShoppingPerformanceView
        ] = ...,
        third_party_app_analytics_link: typing.Optional[
            google.ads.google_ads.v4.proto.resources.third_party_app_analytics_link_pb2.ThirdPartyAppAnalyticsLink
        ] = ...,
        topic_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.topic_view_pb2.TopicView
        ] = ...,
        user_interest: typing.Optional[
            google.ads.google_ads.v4.proto.resources.user_interest_pb2.UserInterest
        ] = ...,
        user_list: typing.Optional[
            google.ads.google_ads.v4.proto.resources.user_list_pb2.UserList
        ] = ...,
        user_location_view: typing.Optional[
            google.ads.google_ads.v4.proto.resources.user_location_view_pb2.UserLocationView
        ] = ...,
        remarketing_action: typing.Optional[
            google.ads.google_ads.v4.proto.resources.remarketing_action_pb2.RemarketingAction
        ] = ...,
        topic_constant: typing.Optional[
            google.ads.google_ads.v4.proto.resources.topic_constant_pb2.TopicConstant
        ] = ...,
        video: typing.Optional[
            google.ads.google_ads.v4.proto.resources.video_pb2.Video
        ] = ...,
        metrics: typing.Optional[
            google.ads.google_ads.v4.proto.common.metrics_pb2.Metrics
        ] = ...,
        segments: typing.Optional[
            google.ads.google_ads.v4.proto.common.segments_pb2.Segments
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "account_budget",
            b"account_budget",
            "account_budget_proposal",
            b"account_budget_proposal",
            "account_link",
            b"account_link",
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_ad_asset_view",
            b"ad_group_ad_asset_view",
            "ad_group_ad_label",
            b"ad_group_ad_label",
            "ad_group_audience_view",
            b"ad_group_audience_view",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_criterion_label",
            b"ad_group_criterion_label",
            "ad_group_criterion_simulation",
            b"ad_group_criterion_simulation",
            "ad_group_extension_setting",
            b"ad_group_extension_setting",
            "ad_group_feed",
            b"ad_group_feed",
            "ad_group_label",
            b"ad_group_label",
            "ad_group_simulation",
            b"ad_group_simulation",
            "ad_parameter",
            b"ad_parameter",
            "ad_schedule_view",
            b"ad_schedule_view",
            "age_range_view",
            b"age_range_view",
            "asset",
            b"asset",
            "batch_job",
            b"batch_job",
            "bidding_strategy",
            b"bidding_strategy",
            "billing_setup",
            b"billing_setup",
            "campaign",
            b"campaign",
            "campaign_audience_view",
            b"campaign_audience_view",
            "campaign_bid_modifier",
            b"campaign_bid_modifier",
            "campaign_budget",
            b"campaign_budget",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_criterion_simulation",
            b"campaign_criterion_simulation",
            "campaign_draft",
            b"campaign_draft",
            "campaign_experiment",
            b"campaign_experiment",
            "campaign_extension_setting",
            b"campaign_extension_setting",
            "campaign_feed",
            b"campaign_feed",
            "campaign_label",
            b"campaign_label",
            "campaign_shared_set",
            b"campaign_shared_set",
            "carrier_constant",
            b"carrier_constant",
            "change_status",
            b"change_status",
            "click_view",
            b"click_view",
            "conversion_action",
            b"conversion_action",
            "currency_constant",
            b"currency_constant",
            "custom_interest",
            b"custom_interest",
            "customer",
            b"customer",
            "customer_client",
            b"customer_client",
            "customer_client_link",
            b"customer_client_link",
            "customer_extension_setting",
            b"customer_extension_setting",
            "customer_feed",
            b"customer_feed",
            "customer_label",
            b"customer_label",
            "customer_manager_link",
            b"customer_manager_link",
            "customer_negative_criterion",
            b"customer_negative_criterion",
            "detail_placement_view",
            b"detail_placement_view",
            "display_keyword_view",
            b"display_keyword_view",
            "distance_view",
            b"distance_view",
            "domain_category",
            b"domain_category",
            "dynamic_search_ads_search_term_view",
            b"dynamic_search_ads_search_term_view",
            "expanded_landing_page_view",
            b"expanded_landing_page_view",
            "extension_feed_item",
            b"extension_feed_item",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "feed_item_target",
            b"feed_item_target",
            "feed_mapping",
            b"feed_mapping",
            "feed_placeholder_view",
            b"feed_placeholder_view",
            "gender_view",
            b"gender_view",
            "geo_target_constant",
            b"geo_target_constant",
            "geographic_view",
            b"geographic_view",
            "group_placement_view",
            b"group_placement_view",
            "hotel_group_view",
            b"hotel_group_view",
            "hotel_performance_view",
            b"hotel_performance_view",
            "income_range_view",
            b"income_range_view",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "keyword_plan_campaign_keyword",
            b"keyword_plan_campaign_keyword",
            "keyword_view",
            b"keyword_view",
            "label",
            b"label",
            "landing_page_view",
            b"landing_page_view",
            "language_constant",
            b"language_constant",
            "location_view",
            b"location_view",
            "managed_placement_view",
            b"managed_placement_view",
            "media_file",
            b"media_file",
            "metrics",
            b"metrics",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
            "offline_user_data_job",
            b"offline_user_data_job",
            "operating_system_version_constant",
            b"operating_system_version_constant",
            "paid_organic_search_term_view",
            b"paid_organic_search_term_view",
            "parental_status_view",
            b"parental_status_view",
            "product_bidding_category_constant",
            b"product_bidding_category_constant",
            "product_group_view",
            b"product_group_view",
            "recommendation",
            b"recommendation",
            "remarketing_action",
            b"remarketing_action",
            "search_term_view",
            b"search_term_view",
            "segments",
            b"segments",
            "shared_criterion",
            b"shared_criterion",
            "shared_set",
            b"shared_set",
            "shopping_performance_view",
            b"shopping_performance_view",
            "third_party_app_analytics_link",
            b"third_party_app_analytics_link",
            "topic_constant",
            b"topic_constant",
            "topic_view",
            b"topic_view",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "user_location_view",
            b"user_location_view",
            "video",
            b"video",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "account_budget",
            b"account_budget",
            "account_budget_proposal",
            b"account_budget_proposal",
            "account_link",
            b"account_link",
            "ad_group",
            b"ad_group",
            "ad_group_ad",
            b"ad_group_ad",
            "ad_group_ad_asset_view",
            b"ad_group_ad_asset_view",
            "ad_group_ad_label",
            b"ad_group_ad_label",
            "ad_group_audience_view",
            b"ad_group_audience_view",
            "ad_group_bid_modifier",
            b"ad_group_bid_modifier",
            "ad_group_criterion",
            b"ad_group_criterion",
            "ad_group_criterion_label",
            b"ad_group_criterion_label",
            "ad_group_criterion_simulation",
            b"ad_group_criterion_simulation",
            "ad_group_extension_setting",
            b"ad_group_extension_setting",
            "ad_group_feed",
            b"ad_group_feed",
            "ad_group_label",
            b"ad_group_label",
            "ad_group_simulation",
            b"ad_group_simulation",
            "ad_parameter",
            b"ad_parameter",
            "ad_schedule_view",
            b"ad_schedule_view",
            "age_range_view",
            b"age_range_view",
            "asset",
            b"asset",
            "batch_job",
            b"batch_job",
            "bidding_strategy",
            b"bidding_strategy",
            "billing_setup",
            b"billing_setup",
            "campaign",
            b"campaign",
            "campaign_audience_view",
            b"campaign_audience_view",
            "campaign_bid_modifier",
            b"campaign_bid_modifier",
            "campaign_budget",
            b"campaign_budget",
            "campaign_criterion",
            b"campaign_criterion",
            "campaign_criterion_simulation",
            b"campaign_criterion_simulation",
            "campaign_draft",
            b"campaign_draft",
            "campaign_experiment",
            b"campaign_experiment",
            "campaign_extension_setting",
            b"campaign_extension_setting",
            "campaign_feed",
            b"campaign_feed",
            "campaign_label",
            b"campaign_label",
            "campaign_shared_set",
            b"campaign_shared_set",
            "carrier_constant",
            b"carrier_constant",
            "change_status",
            b"change_status",
            "click_view",
            b"click_view",
            "conversion_action",
            b"conversion_action",
            "currency_constant",
            b"currency_constant",
            "custom_interest",
            b"custom_interest",
            "customer",
            b"customer",
            "customer_client",
            b"customer_client",
            "customer_client_link",
            b"customer_client_link",
            "customer_extension_setting",
            b"customer_extension_setting",
            "customer_feed",
            b"customer_feed",
            "customer_label",
            b"customer_label",
            "customer_manager_link",
            b"customer_manager_link",
            "customer_negative_criterion",
            b"customer_negative_criterion",
            "detail_placement_view",
            b"detail_placement_view",
            "display_keyword_view",
            b"display_keyword_view",
            "distance_view",
            b"distance_view",
            "domain_category",
            b"domain_category",
            "dynamic_search_ads_search_term_view",
            b"dynamic_search_ads_search_term_view",
            "expanded_landing_page_view",
            b"expanded_landing_page_view",
            "extension_feed_item",
            b"extension_feed_item",
            "feed",
            b"feed",
            "feed_item",
            b"feed_item",
            "feed_item_target",
            b"feed_item_target",
            "feed_mapping",
            b"feed_mapping",
            "feed_placeholder_view",
            b"feed_placeholder_view",
            "gender_view",
            b"gender_view",
            "geo_target_constant",
            b"geo_target_constant",
            "geographic_view",
            b"geographic_view",
            "group_placement_view",
            b"group_placement_view",
            "hotel_group_view",
            b"hotel_group_view",
            "hotel_performance_view",
            b"hotel_performance_view",
            "income_range_view",
            b"income_range_view",
            "keyword_plan",
            b"keyword_plan",
            "keyword_plan_ad_group",
            b"keyword_plan_ad_group",
            "keyword_plan_ad_group_keyword",
            b"keyword_plan_ad_group_keyword",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "keyword_plan_campaign_keyword",
            b"keyword_plan_campaign_keyword",
            "keyword_view",
            b"keyword_view",
            "label",
            b"label",
            "landing_page_view",
            b"landing_page_view",
            "language_constant",
            b"language_constant",
            "location_view",
            b"location_view",
            "managed_placement_view",
            b"managed_placement_view",
            "media_file",
            b"media_file",
            "metrics",
            b"metrics",
            "mobile_app_category_constant",
            b"mobile_app_category_constant",
            "mobile_device_constant",
            b"mobile_device_constant",
            "offline_user_data_job",
            b"offline_user_data_job",
            "operating_system_version_constant",
            b"operating_system_version_constant",
            "paid_organic_search_term_view",
            b"paid_organic_search_term_view",
            "parental_status_view",
            b"parental_status_view",
            "product_bidding_category_constant",
            b"product_bidding_category_constant",
            "product_group_view",
            b"product_group_view",
            "recommendation",
            b"recommendation",
            "remarketing_action",
            b"remarketing_action",
            "search_term_view",
            b"search_term_view",
            "segments",
            b"segments",
            "shared_criterion",
            b"shared_criterion",
            "shared_set",
            b"shared_set",
            "shopping_performance_view",
            b"shopping_performance_view",
            "third_party_app_analytics_link",
            b"third_party_app_analytics_link",
            "topic_constant",
            b"topic_constant",
            "topic_view",
            b"topic_view",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "user_location_view",
            b"user_location_view",
            "video",
            b"video",
        ],
    ) -> None: ...

global___GoogleAdsRow = GoogleAdsRow

class MutateGoogleAdsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    MUTATE_OPERATIONS_FIELD_NUMBER: builtins.int
    PARTIAL_FAILURE_FIELD_NUMBER: builtins.int
    VALIDATE_ONLY_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    partial_failure: builtins.bool = ...
    validate_only: builtins.bool = ...
    @property
    def mutate_operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        mutate_operations: typing.Optional[
            typing.Iterable[global___MutateOperation]
        ] = ...,
        partial_failure: builtins.bool = ...,
        validate_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id",
            b"customer_id",
            "mutate_operations",
            b"mutate_operations",
            "partial_failure",
            b"partial_failure",
            "validate_only",
            b"validate_only",
        ],
    ) -> None: ...

global___MutateGoogleAdsRequest = MutateGoogleAdsRequest

class MutateGoogleAdsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARTIAL_FAILURE_ERROR_FIELD_NUMBER: builtins.int
    MUTATE_OPERATION_RESPONSES_FIELD_NUMBER: builtins.int
    @property
    def partial_failure_error(self) -> google.rpc.status_pb2.Status: ...
    @property
    def mutate_operation_responses(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___MutateOperationResponse
    ]: ...
    def __init__(
        self,
        *,
        partial_failure_error: typing.Optional[google.rpc.status_pb2.Status] = ...,
        mutate_operation_responses: typing.Optional[
            typing.Iterable[global___MutateOperationResponse]
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operation_responses",
            b"mutate_operation_responses",
            "partial_failure_error",
            b"partial_failure_error",
        ],
    ) -> None: ...

global___MutateGoogleAdsResponse = MutateGoogleAdsResponse

class MutateOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_GROUP_AD_LABEL_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_LABEL_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_EXTENSION_SETTING_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_LABEL_OPERATION_FIELD_NUMBER: builtins.int
    AD_GROUP_OPERATION_FIELD_NUMBER: builtins.int
    AD_OPERATION_FIELD_NUMBER: builtins.int
    AD_PARAMETER_OPERATION_FIELD_NUMBER: builtins.int
    ASSET_OPERATION_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_BID_MODIFIER_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXPERIMENT_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXTENSION_SETTING_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_LABEL_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_OPERATION_FIELD_NUMBER: builtins.int
    CAMPAIGN_SHARED_SET_OPERATION_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_OPERATION_FIELD_NUMBER: builtins.int
    CUSTOMER_EXTENSION_SETTING_OPERATION_FIELD_NUMBER: builtins.int
    CUSTOMER_FEED_OPERATION_FIELD_NUMBER: builtins.int
    CUSTOMER_LABEL_OPERATION_FIELD_NUMBER: builtins.int
    CUSTOMER_NEGATIVE_CRITERION_OPERATION_FIELD_NUMBER: builtins.int
    CUSTOMER_OPERATION_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEM_OPERATION_FIELD_NUMBER: builtins.int
    FEED_ITEM_OPERATION_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_OPERATION_FIELD_NUMBER: builtins.int
    FEED_MAPPING_OPERATION_FIELD_NUMBER: builtins.int
    FEED_OPERATION_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_OPERATION_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_KEYWORD_OPERATION_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_KEYWORD_OPERATION_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_OPERATION_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_OPERATION_FIELD_NUMBER: builtins.int
    LABEL_OPERATION_FIELD_NUMBER: builtins.int
    MEDIA_FILE_OPERATION_FIELD_NUMBER: builtins.int
    REMARKETING_ACTION_OPERATION_FIELD_NUMBER: builtins.int
    SHARED_CRITERION_OPERATION_FIELD_NUMBER: builtins.int
    SHARED_SET_OPERATION_FIELD_NUMBER: builtins.int
    USER_LIST_OPERATION_FIELD_NUMBER: builtins.int
    @property
    def ad_group_ad_label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_ad_label_service_pb2.AdGroupAdLabelOperation: ...
    @property
    def ad_group_ad_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_ad_service_pb2.AdGroupAdOperation: ...
    @property
    def ad_group_bid_modifier_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_bid_modifier_service_pb2.AdGroupBidModifierOperation: ...
    @property
    def ad_group_criterion_label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_criterion_label_service_pb2.AdGroupCriterionLabelOperation: ...
    @property
    def ad_group_criterion_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_criterion_service_pb2.AdGroupCriterionOperation: ...
    @property
    def ad_group_extension_setting_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_extension_setting_service_pb2.AdGroupExtensionSettingOperation: ...
    @property
    def ad_group_feed_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_feed_service_pb2.AdGroupFeedOperation: ...
    @property
    def ad_group_label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_label_service_pb2.AdGroupLabelOperation: ...
    @property
    def ad_group_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_service_pb2.AdGroupOperation: ...
    @property
    def ad_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_service_pb2.AdOperation: ...
    @property
    def ad_parameter_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_parameter_service_pb2.AdParameterOperation: ...
    @property
    def asset_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.asset_service_pb2.AssetOperation: ...
    @property
    def bidding_strategy_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.bidding_strategy_service_pb2.BiddingStrategyOperation: ...
    @property
    def campaign_bid_modifier_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_bid_modifier_service_pb2.CampaignBidModifierOperation: ...
    @property
    def campaign_budget_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_budget_service_pb2.CampaignBudgetOperation: ...
    @property
    def campaign_criterion_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_criterion_service_pb2.CampaignCriterionOperation: ...
    @property
    def campaign_draft_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_draft_service_pb2.CampaignDraftOperation: ...
    @property
    def campaign_experiment_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_experiment_service_pb2.CampaignExperimentOperation: ...
    @property
    def campaign_extension_setting_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_extension_setting_service_pb2.CampaignExtensionSettingOperation: ...
    @property
    def campaign_feed_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_feed_service_pb2.CampaignFeedOperation: ...
    @property
    def campaign_label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_label_service_pb2.CampaignLabelOperation: ...
    @property
    def campaign_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_service_pb2.CampaignOperation: ...
    @property
    def campaign_shared_set_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_shared_set_service_pb2.CampaignSharedSetOperation: ...
    @property
    def conversion_action_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.conversion_action_service_pb2.ConversionActionOperation: ...
    @property
    def customer_extension_setting_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_extension_setting_service_pb2.CustomerExtensionSettingOperation: ...
    @property
    def customer_feed_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_feed_service_pb2.CustomerFeedOperation: ...
    @property
    def customer_label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_label_service_pb2.CustomerLabelOperation: ...
    @property
    def customer_negative_criterion_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_negative_criterion_service_pb2.CustomerNegativeCriterionOperation: ...
    @property
    def customer_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_service_pb2.CustomerOperation: ...
    @property
    def extension_feed_item_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.extension_feed_item_service_pb2.ExtensionFeedItemOperation: ...
    @property
    def feed_item_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_item_service_pb2.FeedItemOperation: ...
    @property
    def feed_item_target_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_item_target_service_pb2.FeedItemTargetOperation: ...
    @property
    def feed_mapping_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_mapping_service_pb2.FeedMappingOperation: ...
    @property
    def feed_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_service_pb2.FeedOperation: ...
    @property
    def keyword_plan_ad_group_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_service_pb2.KeywordPlanAdGroupOperation: ...
    @property
    def keyword_plan_ad_group_keyword_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_keyword_service_pb2.KeywordPlanAdGroupKeywordOperation: ...
    @property
    def keyword_plan_campaign_keyword_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_campaign_keyword_service_pb2.KeywordPlanCampaignKeywordOperation: ...
    @property
    def keyword_plan_campaign_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_campaign_service_pb2.KeywordPlanCampaignOperation: ...
    @property
    def keyword_plan_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_service_pb2.KeywordPlanOperation: ...
    @property
    def label_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.label_service_pb2.LabelOperation: ...
    @property
    def media_file_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.media_file_service_pb2.MediaFileOperation: ...
    @property
    def remarketing_action_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.remarketing_action_service_pb2.RemarketingActionOperation: ...
    @property
    def shared_criterion_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.shared_criterion_service_pb2.SharedCriterionOperation: ...
    @property
    def shared_set_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.shared_set_service_pb2.SharedSetOperation: ...
    @property
    def user_list_operation(
        self,
    ) -> google.ads.google_ads.v4.proto.services.user_list_service_pb2.UserListOperation: ...
    def __init__(
        self,
        *,
        ad_group_ad_label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_ad_label_service_pb2.AdGroupAdLabelOperation
        ] = ...,
        ad_group_ad_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_ad_service_pb2.AdGroupAdOperation
        ] = ...,
        ad_group_bid_modifier_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_bid_modifier_service_pb2.AdGroupBidModifierOperation
        ] = ...,
        ad_group_criterion_label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_criterion_label_service_pb2.AdGroupCriterionLabelOperation
        ] = ...,
        ad_group_criterion_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_criterion_service_pb2.AdGroupCriterionOperation
        ] = ...,
        ad_group_extension_setting_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_extension_setting_service_pb2.AdGroupExtensionSettingOperation
        ] = ...,
        ad_group_feed_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_feed_service_pb2.AdGroupFeedOperation
        ] = ...,
        ad_group_label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_label_service_pb2.AdGroupLabelOperation
        ] = ...,
        ad_group_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_service_pb2.AdGroupOperation
        ] = ...,
        ad_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_service_pb2.AdOperation
        ] = ...,
        ad_parameter_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_parameter_service_pb2.AdParameterOperation
        ] = ...,
        asset_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.asset_service_pb2.AssetOperation
        ] = ...,
        bidding_strategy_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.bidding_strategy_service_pb2.BiddingStrategyOperation
        ] = ...,
        campaign_bid_modifier_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_bid_modifier_service_pb2.CampaignBidModifierOperation
        ] = ...,
        campaign_budget_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_budget_service_pb2.CampaignBudgetOperation
        ] = ...,
        campaign_criterion_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_criterion_service_pb2.CampaignCriterionOperation
        ] = ...,
        campaign_draft_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_draft_service_pb2.CampaignDraftOperation
        ] = ...,
        campaign_experiment_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_experiment_service_pb2.CampaignExperimentOperation
        ] = ...,
        campaign_extension_setting_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_extension_setting_service_pb2.CampaignExtensionSettingOperation
        ] = ...,
        campaign_feed_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_feed_service_pb2.CampaignFeedOperation
        ] = ...,
        campaign_label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_label_service_pb2.CampaignLabelOperation
        ] = ...,
        campaign_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_service_pb2.CampaignOperation
        ] = ...,
        campaign_shared_set_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_shared_set_service_pb2.CampaignSharedSetOperation
        ] = ...,
        conversion_action_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.conversion_action_service_pb2.ConversionActionOperation
        ] = ...,
        customer_extension_setting_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_extension_setting_service_pb2.CustomerExtensionSettingOperation
        ] = ...,
        customer_feed_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_feed_service_pb2.CustomerFeedOperation
        ] = ...,
        customer_label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_label_service_pb2.CustomerLabelOperation
        ] = ...,
        customer_negative_criterion_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_negative_criterion_service_pb2.CustomerNegativeCriterionOperation
        ] = ...,
        customer_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_service_pb2.CustomerOperation
        ] = ...,
        extension_feed_item_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.extension_feed_item_service_pb2.ExtensionFeedItemOperation
        ] = ...,
        feed_item_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_item_service_pb2.FeedItemOperation
        ] = ...,
        feed_item_target_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_item_target_service_pb2.FeedItemTargetOperation
        ] = ...,
        feed_mapping_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_mapping_service_pb2.FeedMappingOperation
        ] = ...,
        feed_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_service_pb2.FeedOperation
        ] = ...,
        keyword_plan_ad_group_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_service_pb2.KeywordPlanAdGroupOperation
        ] = ...,
        keyword_plan_ad_group_keyword_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_keyword_service_pb2.KeywordPlanAdGroupKeywordOperation
        ] = ...,
        keyword_plan_campaign_keyword_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_campaign_keyword_service_pb2.KeywordPlanCampaignKeywordOperation
        ] = ...,
        keyword_plan_campaign_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_campaign_service_pb2.KeywordPlanCampaignOperation
        ] = ...,
        keyword_plan_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_service_pb2.KeywordPlanOperation
        ] = ...,
        label_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.label_service_pb2.LabelOperation
        ] = ...,
        media_file_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.media_file_service_pb2.MediaFileOperation
        ] = ...,
        remarketing_action_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.remarketing_action_service_pb2.RemarketingActionOperation
        ] = ...,
        shared_criterion_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.shared_criterion_service_pb2.SharedCriterionOperation
        ] = ...,
        shared_set_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.shared_set_service_pb2.SharedSetOperation
        ] = ...,
        user_list_operation: typing.Optional[
            google.ads.google_ads.v4.proto.services.user_list_service_pb2.UserListOperation
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group_ad_label_operation",
            b"ad_group_ad_label_operation",
            "ad_group_ad_operation",
            b"ad_group_ad_operation",
            "ad_group_bid_modifier_operation",
            b"ad_group_bid_modifier_operation",
            "ad_group_criterion_label_operation",
            b"ad_group_criterion_label_operation",
            "ad_group_criterion_operation",
            b"ad_group_criterion_operation",
            "ad_group_extension_setting_operation",
            b"ad_group_extension_setting_operation",
            "ad_group_feed_operation",
            b"ad_group_feed_operation",
            "ad_group_label_operation",
            b"ad_group_label_operation",
            "ad_group_operation",
            b"ad_group_operation",
            "ad_operation",
            b"ad_operation",
            "ad_parameter_operation",
            b"ad_parameter_operation",
            "asset_operation",
            b"asset_operation",
            "bidding_strategy_operation",
            b"bidding_strategy_operation",
            "campaign_bid_modifier_operation",
            b"campaign_bid_modifier_operation",
            "campaign_budget_operation",
            b"campaign_budget_operation",
            "campaign_criterion_operation",
            b"campaign_criterion_operation",
            "campaign_draft_operation",
            b"campaign_draft_operation",
            "campaign_experiment_operation",
            b"campaign_experiment_operation",
            "campaign_extension_setting_operation",
            b"campaign_extension_setting_operation",
            "campaign_feed_operation",
            b"campaign_feed_operation",
            "campaign_label_operation",
            b"campaign_label_operation",
            "campaign_operation",
            b"campaign_operation",
            "campaign_shared_set_operation",
            b"campaign_shared_set_operation",
            "conversion_action_operation",
            b"conversion_action_operation",
            "customer_extension_setting_operation",
            b"customer_extension_setting_operation",
            "customer_feed_operation",
            b"customer_feed_operation",
            "customer_label_operation",
            b"customer_label_operation",
            "customer_negative_criterion_operation",
            b"customer_negative_criterion_operation",
            "customer_operation",
            b"customer_operation",
            "extension_feed_item_operation",
            b"extension_feed_item_operation",
            "feed_item_operation",
            b"feed_item_operation",
            "feed_item_target_operation",
            b"feed_item_target_operation",
            "feed_mapping_operation",
            b"feed_mapping_operation",
            "feed_operation",
            b"feed_operation",
            "keyword_plan_ad_group_keyword_operation",
            b"keyword_plan_ad_group_keyword_operation",
            "keyword_plan_ad_group_operation",
            b"keyword_plan_ad_group_operation",
            "keyword_plan_campaign_keyword_operation",
            b"keyword_plan_campaign_keyword_operation",
            "keyword_plan_campaign_operation",
            b"keyword_plan_campaign_operation",
            "keyword_plan_operation",
            b"keyword_plan_operation",
            "label_operation",
            b"label_operation",
            "media_file_operation",
            b"media_file_operation",
            "operation",
            b"operation",
            "remarketing_action_operation",
            b"remarketing_action_operation",
            "shared_criterion_operation",
            b"shared_criterion_operation",
            "shared_set_operation",
            b"shared_set_operation",
            "user_list_operation",
            b"user_list_operation",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group_ad_label_operation",
            b"ad_group_ad_label_operation",
            "ad_group_ad_operation",
            b"ad_group_ad_operation",
            "ad_group_bid_modifier_operation",
            b"ad_group_bid_modifier_operation",
            "ad_group_criterion_label_operation",
            b"ad_group_criterion_label_operation",
            "ad_group_criterion_operation",
            b"ad_group_criterion_operation",
            "ad_group_extension_setting_operation",
            b"ad_group_extension_setting_operation",
            "ad_group_feed_operation",
            b"ad_group_feed_operation",
            "ad_group_label_operation",
            b"ad_group_label_operation",
            "ad_group_operation",
            b"ad_group_operation",
            "ad_operation",
            b"ad_operation",
            "ad_parameter_operation",
            b"ad_parameter_operation",
            "asset_operation",
            b"asset_operation",
            "bidding_strategy_operation",
            b"bidding_strategy_operation",
            "campaign_bid_modifier_operation",
            b"campaign_bid_modifier_operation",
            "campaign_budget_operation",
            b"campaign_budget_operation",
            "campaign_criterion_operation",
            b"campaign_criterion_operation",
            "campaign_draft_operation",
            b"campaign_draft_operation",
            "campaign_experiment_operation",
            b"campaign_experiment_operation",
            "campaign_extension_setting_operation",
            b"campaign_extension_setting_operation",
            "campaign_feed_operation",
            b"campaign_feed_operation",
            "campaign_label_operation",
            b"campaign_label_operation",
            "campaign_operation",
            b"campaign_operation",
            "campaign_shared_set_operation",
            b"campaign_shared_set_operation",
            "conversion_action_operation",
            b"conversion_action_operation",
            "customer_extension_setting_operation",
            b"customer_extension_setting_operation",
            "customer_feed_operation",
            b"customer_feed_operation",
            "customer_label_operation",
            b"customer_label_operation",
            "customer_negative_criterion_operation",
            b"customer_negative_criterion_operation",
            "customer_operation",
            b"customer_operation",
            "extension_feed_item_operation",
            b"extension_feed_item_operation",
            "feed_item_operation",
            b"feed_item_operation",
            "feed_item_target_operation",
            b"feed_item_target_operation",
            "feed_mapping_operation",
            b"feed_mapping_operation",
            "feed_operation",
            b"feed_operation",
            "keyword_plan_ad_group_keyword_operation",
            b"keyword_plan_ad_group_keyword_operation",
            "keyword_plan_ad_group_operation",
            b"keyword_plan_ad_group_operation",
            "keyword_plan_campaign_keyword_operation",
            b"keyword_plan_campaign_keyword_operation",
            "keyword_plan_campaign_operation",
            b"keyword_plan_campaign_operation",
            "keyword_plan_operation",
            b"keyword_plan_operation",
            "label_operation",
            b"label_operation",
            "media_file_operation",
            b"media_file_operation",
            "operation",
            b"operation",
            "remarketing_action_operation",
            b"remarketing_action_operation",
            "shared_criterion_operation",
            b"shared_criterion_operation",
            "shared_set_operation",
            b"shared_set_operation",
            "user_list_operation",
            b"user_list_operation",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal[
        "ad_group_ad_label_operation",
        "ad_group_ad_operation",
        "ad_group_bid_modifier_operation",
        "ad_group_criterion_label_operation",
        "ad_group_criterion_operation",
        "ad_group_extension_setting_operation",
        "ad_group_feed_operation",
        "ad_group_label_operation",
        "ad_group_operation",
        "ad_operation",
        "ad_parameter_operation",
        "asset_operation",
        "bidding_strategy_operation",
        "campaign_bid_modifier_operation",
        "campaign_budget_operation",
        "campaign_criterion_operation",
        "campaign_draft_operation",
        "campaign_experiment_operation",
        "campaign_extension_setting_operation",
        "campaign_feed_operation",
        "campaign_label_operation",
        "campaign_operation",
        "campaign_shared_set_operation",
        "conversion_action_operation",
        "customer_extension_setting_operation",
        "customer_feed_operation",
        "customer_label_operation",
        "customer_negative_criterion_operation",
        "customer_operation",
        "extension_feed_item_operation",
        "feed_item_operation",
        "feed_item_target_operation",
        "feed_mapping_operation",
        "feed_operation",
        "keyword_plan_ad_group_operation",
        "keyword_plan_ad_group_keyword_operation",
        "keyword_plan_campaign_keyword_operation",
        "keyword_plan_campaign_operation",
        "keyword_plan_operation",
        "label_operation",
        "media_file_operation",
        "remarketing_action_operation",
        "shared_criterion_operation",
        "shared_set_operation",
        "user_list_operation",
    ]: ...

global___MutateOperation = MutateOperation

class MutateOperationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AD_GROUP_AD_LABEL_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_BID_MODIFIER_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_LABEL_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_CRITERION_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_EXTENSION_SETTING_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_FEED_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_LABEL_RESULT_FIELD_NUMBER: builtins.int
    AD_GROUP_RESULT_FIELD_NUMBER: builtins.int
    AD_PARAMETER_RESULT_FIELD_NUMBER: builtins.int
    AD_RESULT_FIELD_NUMBER: builtins.int
    ASSET_RESULT_FIELD_NUMBER: builtins.int
    BIDDING_STRATEGY_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_BID_MODIFIER_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_BUDGET_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_CRITERION_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_DRAFT_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXPERIMENT_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_EXTENSION_SETTING_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_FEED_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_LABEL_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_RESULT_FIELD_NUMBER: builtins.int
    CAMPAIGN_SHARED_SET_RESULT_FIELD_NUMBER: builtins.int
    CONVERSION_ACTION_RESULT_FIELD_NUMBER: builtins.int
    CUSTOMER_EXTENSION_SETTING_RESULT_FIELD_NUMBER: builtins.int
    CUSTOMER_FEED_RESULT_FIELD_NUMBER: builtins.int
    CUSTOMER_LABEL_RESULT_FIELD_NUMBER: builtins.int
    CUSTOMER_NEGATIVE_CRITERION_RESULT_FIELD_NUMBER: builtins.int
    CUSTOMER_RESULT_FIELD_NUMBER: builtins.int
    EXTENSION_FEED_ITEM_RESULT_FIELD_NUMBER: builtins.int
    FEED_ITEM_RESULT_FIELD_NUMBER: builtins.int
    FEED_ITEM_TARGET_RESULT_FIELD_NUMBER: builtins.int
    FEED_MAPPING_RESULT_FIELD_NUMBER: builtins.int
    FEED_RESULT_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_RESULT_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_RESULT_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_AD_GROUP_KEYWORD_RESULT_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_KEYWORD_RESULT_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_RESULT_FIELD_NUMBER: builtins.int
    LABEL_RESULT_FIELD_NUMBER: builtins.int
    MEDIA_FILE_RESULT_FIELD_NUMBER: builtins.int
    REMARKETING_ACTION_RESULT_FIELD_NUMBER: builtins.int
    SHARED_CRITERION_RESULT_FIELD_NUMBER: builtins.int
    SHARED_SET_RESULT_FIELD_NUMBER: builtins.int
    USER_LIST_RESULT_FIELD_NUMBER: builtins.int
    @property
    def ad_group_ad_label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_ad_label_service_pb2.MutateAdGroupAdLabelResult: ...
    @property
    def ad_group_ad_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_ad_service_pb2.MutateAdGroupAdResult: ...
    @property
    def ad_group_bid_modifier_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_bid_modifier_service_pb2.MutateAdGroupBidModifierResult: ...
    @property
    def ad_group_criterion_label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_criterion_label_service_pb2.MutateAdGroupCriterionLabelResult: ...
    @property
    def ad_group_criterion_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_criterion_service_pb2.MutateAdGroupCriterionResult: ...
    @property
    def ad_group_extension_setting_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_extension_setting_service_pb2.MutateAdGroupExtensionSettingResult: ...
    @property
    def ad_group_feed_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_feed_service_pb2.MutateAdGroupFeedResult: ...
    @property
    def ad_group_label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_label_service_pb2.MutateAdGroupLabelResult: ...
    @property
    def ad_group_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_group_service_pb2.MutateAdGroupResult: ...
    @property
    def ad_parameter_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_parameter_service_pb2.MutateAdParameterResult: ...
    @property
    def ad_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.ad_service_pb2.MutateAdResult: ...
    @property
    def asset_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.asset_service_pb2.MutateAssetResult: ...
    @property
    def bidding_strategy_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.bidding_strategy_service_pb2.MutateBiddingStrategyResult: ...
    @property
    def campaign_bid_modifier_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_bid_modifier_service_pb2.MutateCampaignBidModifierResult: ...
    @property
    def campaign_budget_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_budget_service_pb2.MutateCampaignBudgetResult: ...
    @property
    def campaign_criterion_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_criterion_service_pb2.MutateCampaignCriterionResult: ...
    @property
    def campaign_draft_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_draft_service_pb2.MutateCampaignDraftResult: ...
    @property
    def campaign_experiment_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_experiment_service_pb2.MutateCampaignExperimentResult: ...
    @property
    def campaign_extension_setting_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_extension_setting_service_pb2.MutateCampaignExtensionSettingResult: ...
    @property
    def campaign_feed_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_feed_service_pb2.MutateCampaignFeedResult: ...
    @property
    def campaign_label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_label_service_pb2.MutateCampaignLabelResult: ...
    @property
    def campaign_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_service_pb2.MutateCampaignResult: ...
    @property
    def campaign_shared_set_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.campaign_shared_set_service_pb2.MutateCampaignSharedSetResult: ...
    @property
    def conversion_action_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.conversion_action_service_pb2.MutateConversionActionResult: ...
    @property
    def customer_extension_setting_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_extension_setting_service_pb2.MutateCustomerExtensionSettingResult: ...
    @property
    def customer_feed_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_feed_service_pb2.MutateCustomerFeedResult: ...
    @property
    def customer_label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_label_service_pb2.MutateCustomerLabelResult: ...
    @property
    def customer_negative_criterion_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_negative_criterion_service_pb2.MutateCustomerNegativeCriteriaResult: ...
    @property
    def customer_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.customer_service_pb2.MutateCustomerResult: ...
    @property
    def extension_feed_item_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.extension_feed_item_service_pb2.MutateExtensionFeedItemResult: ...
    @property
    def feed_item_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_item_service_pb2.MutateFeedItemResult: ...
    @property
    def feed_item_target_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_item_target_service_pb2.MutateFeedItemTargetResult: ...
    @property
    def feed_mapping_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_mapping_service_pb2.MutateFeedMappingResult: ...
    @property
    def feed_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.feed_service_pb2.MutateFeedResult: ...
    @property
    def keyword_plan_ad_group_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_service_pb2.MutateKeywordPlanAdGroupResult: ...
    @property
    def keyword_plan_campaign_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_campaign_service_pb2.MutateKeywordPlanCampaignResult: ...
    @property
    def keyword_plan_ad_group_keyword_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_keyword_service_pb2.MutateKeywordPlanAdGroupKeywordResult: ...
    @property
    def keyword_plan_campaign_keyword_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_campaign_keyword_service_pb2.MutateKeywordPlanCampaignKeywordResult: ...
    @property
    def keyword_plan_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.keyword_plan_service_pb2.MutateKeywordPlansResult: ...
    @property
    def label_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.label_service_pb2.MutateLabelResult: ...
    @property
    def media_file_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.media_file_service_pb2.MutateMediaFileResult: ...
    @property
    def remarketing_action_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.remarketing_action_service_pb2.MutateRemarketingActionResult: ...
    @property
    def shared_criterion_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.shared_criterion_service_pb2.MutateSharedCriterionResult: ...
    @property
    def shared_set_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.shared_set_service_pb2.MutateSharedSetResult: ...
    @property
    def user_list_result(
        self,
    ) -> google.ads.google_ads.v4.proto.services.user_list_service_pb2.MutateUserListResult: ...
    def __init__(
        self,
        *,
        ad_group_ad_label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_ad_label_service_pb2.MutateAdGroupAdLabelResult
        ] = ...,
        ad_group_ad_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_ad_service_pb2.MutateAdGroupAdResult
        ] = ...,
        ad_group_bid_modifier_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_bid_modifier_service_pb2.MutateAdGroupBidModifierResult
        ] = ...,
        ad_group_criterion_label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_criterion_label_service_pb2.MutateAdGroupCriterionLabelResult
        ] = ...,
        ad_group_criterion_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_criterion_service_pb2.MutateAdGroupCriterionResult
        ] = ...,
        ad_group_extension_setting_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_extension_setting_service_pb2.MutateAdGroupExtensionSettingResult
        ] = ...,
        ad_group_feed_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_feed_service_pb2.MutateAdGroupFeedResult
        ] = ...,
        ad_group_label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_label_service_pb2.MutateAdGroupLabelResult
        ] = ...,
        ad_group_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_group_service_pb2.MutateAdGroupResult
        ] = ...,
        ad_parameter_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_parameter_service_pb2.MutateAdParameterResult
        ] = ...,
        ad_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.ad_service_pb2.MutateAdResult
        ] = ...,
        asset_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.asset_service_pb2.MutateAssetResult
        ] = ...,
        bidding_strategy_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.bidding_strategy_service_pb2.MutateBiddingStrategyResult
        ] = ...,
        campaign_bid_modifier_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_bid_modifier_service_pb2.MutateCampaignBidModifierResult
        ] = ...,
        campaign_budget_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_budget_service_pb2.MutateCampaignBudgetResult
        ] = ...,
        campaign_criterion_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_criterion_service_pb2.MutateCampaignCriterionResult
        ] = ...,
        campaign_draft_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_draft_service_pb2.MutateCampaignDraftResult
        ] = ...,
        campaign_experiment_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_experiment_service_pb2.MutateCampaignExperimentResult
        ] = ...,
        campaign_extension_setting_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_extension_setting_service_pb2.MutateCampaignExtensionSettingResult
        ] = ...,
        campaign_feed_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_feed_service_pb2.MutateCampaignFeedResult
        ] = ...,
        campaign_label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_label_service_pb2.MutateCampaignLabelResult
        ] = ...,
        campaign_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_service_pb2.MutateCampaignResult
        ] = ...,
        campaign_shared_set_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.campaign_shared_set_service_pb2.MutateCampaignSharedSetResult
        ] = ...,
        conversion_action_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.conversion_action_service_pb2.MutateConversionActionResult
        ] = ...,
        customer_extension_setting_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_extension_setting_service_pb2.MutateCustomerExtensionSettingResult
        ] = ...,
        customer_feed_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_feed_service_pb2.MutateCustomerFeedResult
        ] = ...,
        customer_label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_label_service_pb2.MutateCustomerLabelResult
        ] = ...,
        customer_negative_criterion_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_negative_criterion_service_pb2.MutateCustomerNegativeCriteriaResult
        ] = ...,
        customer_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.customer_service_pb2.MutateCustomerResult
        ] = ...,
        extension_feed_item_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.extension_feed_item_service_pb2.MutateExtensionFeedItemResult
        ] = ...,
        feed_item_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_item_service_pb2.MutateFeedItemResult
        ] = ...,
        feed_item_target_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_item_target_service_pb2.MutateFeedItemTargetResult
        ] = ...,
        feed_mapping_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_mapping_service_pb2.MutateFeedMappingResult
        ] = ...,
        feed_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.feed_service_pb2.MutateFeedResult
        ] = ...,
        keyword_plan_ad_group_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_service_pb2.MutateKeywordPlanAdGroupResult
        ] = ...,
        keyword_plan_campaign_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_campaign_service_pb2.MutateKeywordPlanCampaignResult
        ] = ...,
        keyword_plan_ad_group_keyword_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_ad_group_keyword_service_pb2.MutateKeywordPlanAdGroupKeywordResult
        ] = ...,
        keyword_plan_campaign_keyword_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_campaign_keyword_service_pb2.MutateKeywordPlanCampaignKeywordResult
        ] = ...,
        keyword_plan_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.keyword_plan_service_pb2.MutateKeywordPlansResult
        ] = ...,
        label_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.label_service_pb2.MutateLabelResult
        ] = ...,
        media_file_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.media_file_service_pb2.MutateMediaFileResult
        ] = ...,
        remarketing_action_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.remarketing_action_service_pb2.MutateRemarketingActionResult
        ] = ...,
        shared_criterion_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.shared_criterion_service_pb2.MutateSharedCriterionResult
        ] = ...,
        shared_set_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.shared_set_service_pb2.MutateSharedSetResult
        ] = ...,
        user_list_result: typing.Optional[
            google.ads.google_ads.v4.proto.services.user_list_service_pb2.MutateUserListResult
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group_ad_label_result",
            b"ad_group_ad_label_result",
            "ad_group_ad_result",
            b"ad_group_ad_result",
            "ad_group_bid_modifier_result",
            b"ad_group_bid_modifier_result",
            "ad_group_criterion_label_result",
            b"ad_group_criterion_label_result",
            "ad_group_criterion_result",
            b"ad_group_criterion_result",
            "ad_group_extension_setting_result",
            b"ad_group_extension_setting_result",
            "ad_group_feed_result",
            b"ad_group_feed_result",
            "ad_group_label_result",
            b"ad_group_label_result",
            "ad_group_result",
            b"ad_group_result",
            "ad_parameter_result",
            b"ad_parameter_result",
            "ad_result",
            b"ad_result",
            "asset_result",
            b"asset_result",
            "bidding_strategy_result",
            b"bidding_strategy_result",
            "campaign_bid_modifier_result",
            b"campaign_bid_modifier_result",
            "campaign_budget_result",
            b"campaign_budget_result",
            "campaign_criterion_result",
            b"campaign_criterion_result",
            "campaign_draft_result",
            b"campaign_draft_result",
            "campaign_experiment_result",
            b"campaign_experiment_result",
            "campaign_extension_setting_result",
            b"campaign_extension_setting_result",
            "campaign_feed_result",
            b"campaign_feed_result",
            "campaign_label_result",
            b"campaign_label_result",
            "campaign_result",
            b"campaign_result",
            "campaign_shared_set_result",
            b"campaign_shared_set_result",
            "conversion_action_result",
            b"conversion_action_result",
            "customer_extension_setting_result",
            b"customer_extension_setting_result",
            "customer_feed_result",
            b"customer_feed_result",
            "customer_label_result",
            b"customer_label_result",
            "customer_negative_criterion_result",
            b"customer_negative_criterion_result",
            "customer_result",
            b"customer_result",
            "extension_feed_item_result",
            b"extension_feed_item_result",
            "feed_item_result",
            b"feed_item_result",
            "feed_item_target_result",
            b"feed_item_target_result",
            "feed_mapping_result",
            b"feed_mapping_result",
            "feed_result",
            b"feed_result",
            "keyword_plan_ad_group_keyword_result",
            b"keyword_plan_ad_group_keyword_result",
            "keyword_plan_ad_group_result",
            b"keyword_plan_ad_group_result",
            "keyword_plan_campaign_keyword_result",
            b"keyword_plan_campaign_keyword_result",
            "keyword_plan_campaign_result",
            b"keyword_plan_campaign_result",
            "keyword_plan_result",
            b"keyword_plan_result",
            "label_result",
            b"label_result",
            "media_file_result",
            b"media_file_result",
            "remarketing_action_result",
            b"remarketing_action_result",
            "response",
            b"response",
            "shared_criterion_result",
            b"shared_criterion_result",
            "shared_set_result",
            b"shared_set_result",
            "user_list_result",
            b"user_list_result",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_group_ad_label_result",
            b"ad_group_ad_label_result",
            "ad_group_ad_result",
            b"ad_group_ad_result",
            "ad_group_bid_modifier_result",
            b"ad_group_bid_modifier_result",
            "ad_group_criterion_label_result",
            b"ad_group_criterion_label_result",
            "ad_group_criterion_result",
            b"ad_group_criterion_result",
            "ad_group_extension_setting_result",
            b"ad_group_extension_setting_result",
            "ad_group_feed_result",
            b"ad_group_feed_result",
            "ad_group_label_result",
            b"ad_group_label_result",
            "ad_group_result",
            b"ad_group_result",
            "ad_parameter_result",
            b"ad_parameter_result",
            "ad_result",
            b"ad_result",
            "asset_result",
            b"asset_result",
            "bidding_strategy_result",
            b"bidding_strategy_result",
            "campaign_bid_modifier_result",
            b"campaign_bid_modifier_result",
            "campaign_budget_result",
            b"campaign_budget_result",
            "campaign_criterion_result",
            b"campaign_criterion_result",
            "campaign_draft_result",
            b"campaign_draft_result",
            "campaign_experiment_result",
            b"campaign_experiment_result",
            "campaign_extension_setting_result",
            b"campaign_extension_setting_result",
            "campaign_feed_result",
            b"campaign_feed_result",
            "campaign_label_result",
            b"campaign_label_result",
            "campaign_result",
            b"campaign_result",
            "campaign_shared_set_result",
            b"campaign_shared_set_result",
            "conversion_action_result",
            b"conversion_action_result",
            "customer_extension_setting_result",
            b"customer_extension_setting_result",
            "customer_feed_result",
            b"customer_feed_result",
            "customer_label_result",
            b"customer_label_result",
            "customer_negative_criterion_result",
            b"customer_negative_criterion_result",
            "customer_result",
            b"customer_result",
            "extension_feed_item_result",
            b"extension_feed_item_result",
            "feed_item_result",
            b"feed_item_result",
            "feed_item_target_result",
            b"feed_item_target_result",
            "feed_mapping_result",
            b"feed_mapping_result",
            "feed_result",
            b"feed_result",
            "keyword_plan_ad_group_keyword_result",
            b"keyword_plan_ad_group_keyword_result",
            "keyword_plan_ad_group_result",
            b"keyword_plan_ad_group_result",
            "keyword_plan_campaign_keyword_result",
            b"keyword_plan_campaign_keyword_result",
            "keyword_plan_campaign_result",
            b"keyword_plan_campaign_result",
            "keyword_plan_result",
            b"keyword_plan_result",
            "label_result",
            b"label_result",
            "media_file_result",
            b"media_file_result",
            "remarketing_action_result",
            b"remarketing_action_result",
            "response",
            b"response",
            "shared_criterion_result",
            b"shared_criterion_result",
            "shared_set_result",
            b"shared_set_result",
            "user_list_result",
            b"user_list_result",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["response", b"response"]
    ) -> typing_extensions.Literal[
        "ad_group_ad_label_result",
        "ad_group_ad_result",
        "ad_group_bid_modifier_result",
        "ad_group_criterion_label_result",
        "ad_group_criterion_result",
        "ad_group_extension_setting_result",
        "ad_group_feed_result",
        "ad_group_label_result",
        "ad_group_result",
        "ad_parameter_result",
        "ad_result",
        "asset_result",
        "bidding_strategy_result",
        "campaign_bid_modifier_result",
        "campaign_budget_result",
        "campaign_criterion_result",
        "campaign_draft_result",
        "campaign_experiment_result",
        "campaign_extension_setting_result",
        "campaign_feed_result",
        "campaign_label_result",
        "campaign_result",
        "campaign_shared_set_result",
        "conversion_action_result",
        "customer_extension_setting_result",
        "customer_feed_result",
        "customer_label_result",
        "customer_negative_criterion_result",
        "customer_result",
        "extension_feed_item_result",
        "feed_item_result",
        "feed_item_target_result",
        "feed_mapping_result",
        "feed_result",
        "keyword_plan_ad_group_result",
        "keyword_plan_campaign_result",
        "keyword_plan_ad_group_keyword_result",
        "keyword_plan_campaign_keyword_result",
        "keyword_plan_result",
        "label_result",
        "media_file_result",
        "remarketing_action_result",
        "shared_criterion_result",
        "shared_set_result",
        "user_list_result",
    ]: ...

global___MutateOperationResponse = MutateOperationResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.batch_job_pb2
import google.longrunning.operations_pb2
import grpc

from .batch_job_service_pb2 import *

class BatchJobServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def MutateBatchJob(
        self,
        request: global___MutateBatchJobRequest,
    ) -> global___MutateBatchJobResponse: ...
    def GetBatchJob(
        self,
        request: global___GetBatchJobRequest,
    ) -> google.ads.google_ads.v4.proto.resources.batch_job_pb2.BatchJob: ...
    def ListBatchJobResults(
        self,
        request: global___ListBatchJobResultsRequest,
    ) -> global___ListBatchJobResultsResponse: ...
    def RunBatchJob(
        self,
        request: global___RunBatchJobRequest,
    ) -> google.longrunning.operations_pb2.Operation: ...
    def AddBatchJobOperations(
        self,
        request: global___AddBatchJobOperationsRequest,
    ) -> global___AddBatchJobOperationsResponse: ...

class BatchJobServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def MutateBatchJob(
        self,
        request: global___MutateBatchJobRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateBatchJobResponse: ...
    @abc.abstractmethod
    def GetBatchJob(
        self,
        request: global___GetBatchJobRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.batch_job_pb2.BatchJob: ...
    @abc.abstractmethod
    def ListBatchJobResults(
        self,
        request: global___ListBatchJobResultsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListBatchJobResultsResponse: ...
    @abc.abstractmethod
    def RunBatchJob(
        self,
        request: global___RunBatchJobRequest,
        context: grpc.ServicerContext,
    ) -> google.longrunning.operations_pb2.Operation: ...
    @abc.abstractmethod
    def AddBatchJobOperations(
        self,
        request: global___AddBatchJobOperationsRequest,
        context: grpc.ServicerContext,
    ) -> global___AddBatchJobOperationsResponse: ...

def add_BatchJobServiceServicer_to_server(
    servicer: BatchJobServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusOperationEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusOperation(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusOperation.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusOperationEnum.ChangeStatusOperation.V(0)
        UNKNOWN = ChangeStatusOperationEnum.ChangeStatusOperation.V(1)
        ADDED = ChangeStatusOperationEnum.ChangeStatusOperation.V(2)
        CHANGED = ChangeStatusOperationEnum.ChangeStatusOperation.V(3)
        REMOVED = ChangeStatusOperationEnum.ChangeStatusOperation.V(4)
    class ChangeStatusOperation(metaclass=_ChangeStatusOperation):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusOperationEnum.ChangeStatusOperation.V(0)
    UNKNOWN = ChangeStatusOperationEnum.ChangeStatusOperation.V(1)
    ADDED = ChangeStatusOperationEnum.ChangeStatusOperation.V(2)
    CHANGED = ChangeStatusOperationEnum.ChangeStatusOperation.V(3)
    REMOVED = ChangeStatusOperationEnum.ChangeStatusOperation.V(4)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusOperationEnum = ChangeStatusOperationEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeEventResourceTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeEventResourceType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeEventResourceType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(0)
        UNKNOWN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(1)
        AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(2)
        AD_GROUP = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(3)
        AD_GROUP_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(4)
        CAMPAIGN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(5)
        CAMPAIGN_BUDGET = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(6)
        AD_GROUP_BID_MODIFIER = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(7)
        CAMPAIGN_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(8)
        FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(9)
        FEED_ITEM = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(10)
        CAMPAIGN_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(11)
        AD_GROUP_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(12)
        AD_GROUP_AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(13)
    class ChangeEventResourceType(metaclass=_ChangeEventResourceType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(0)
    UNKNOWN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(1)
    AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(2)
    AD_GROUP = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(3)
    AD_GROUP_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(4)
    CAMPAIGN = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(5)
    CAMPAIGN_BUDGET = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(6)
    AD_GROUP_BID_MODIFIER = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(7)
    CAMPAIGN_CRITERION = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(8)
    FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(9)
    FEED_ITEM = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(10)
    CAMPAIGN_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(11)
    AD_GROUP_FEED = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(12)
    AD_GROUP_AD = ChangeEventResourceTypeEnum.ChangeEventResourceType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeEventResourceTypeEnum = ChangeEventResourceTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class HotelRateTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _HotelRateType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HotelRateType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = HotelRateTypeEnum.HotelRateType.V(0)
        UNKNOWN = HotelRateTypeEnum.HotelRateType.V(1)
        UNAVAILABLE = HotelRateTypeEnum.HotelRateType.V(2)
        PUBLIC_RATE = HotelRateTypeEnum.HotelRateType.V(3)
        QUALIFIED_RATE = HotelRateTypeEnum.HotelRateType.V(4)
        PRIVATE_RATE = HotelRateTypeEnum.HotelRateType.V(5)
    class HotelRateType(metaclass=_HotelRateType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = HotelRateTypeEnum.HotelRateType.V(0)
    UNKNOWN = HotelRateTypeEnum.HotelRateType.V(1)
    UNAVAILABLE = HotelRateTypeEnum.HotelRateType.V(2)
    PUBLIC_RATE = HotelRateTypeEnum.HotelRateType.V(3)
    QUALIFIED_RATE = HotelRateTypeEnum.HotelRateType.V(4)
    PRIVATE_RATE = HotelRateTypeEnum.HotelRateType.V(5)
    def __init__(
        self,
    ) -> None: ...

global___HotelRateTypeEnum = HotelRateTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdSharingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdSharingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdSharingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AdSharingErrorEnum.AdSharingError.V(0)
        UNKNOWN = AdSharingErrorEnum.AdSharingError.V(1)
        AD_GROUP_ALREADY_CONTAINS_AD = AdSharingErrorEnum.AdSharingError.V(2)
        INCOMPATIBLE_AD_UNDER_AD_GROUP = AdSharingErrorEnum.AdSharingError.V(3)
        CANNOT_SHARE_INACTIVE_AD = AdSharingErrorEnum.AdSharingError.V(4)
    class AdSharingError(metaclass=_AdSharingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdSharingErrorEnum.AdSharingError.V(0)
    UNKNOWN = AdSharingErrorEnum.AdSharingError.V(1)
    AD_GROUP_ALREADY_CONTAINS_AD = AdSharingErrorEnum.AdSharingError.V(2)
    INCOMPATIBLE_AD_UNDER_AD_GROUP = AdSharingErrorEnum.AdSharingError.V(3)
    CANNOT_SHARE_INACTIVE_AD = AdSharingErrorEnum.AdSharingError.V(4)
    def __init__(
        self,
    ) -> None: ...

global___AdSharingErrorEnum = AdSharingErrorEnum
